class JsonRPCURLs:
    """
    This class contains the URLs for the JSON-RPC API.
    """

    XRP_LEDGER_FOUNDATION_MAINNET_1 = "https://xrplcluster.com/"
    XRP_LEDGER_FOUNDATION_MAINNET_2 = "https://xrpl.ws/"

    RIPPLE_MAINNET_1 = "https://s1.ripple.com:51234/"
    RIPPLE_MAINNET_2 = "https://s2.ripple.com:51234/"

    RIPPLE_TESTNET = "https://s.altnet.rippletest.net:51234/"

    RIPPLE_DEVNET = "https://s.devnet.rippletest.net:51234/"


class WebsocketURLs:
    """
    This class contains the URLs for the Websocket API.
    """

    XRP_LEDGER_FOUNDATION_MAINNET_1 = "wss://xrplcluster.com/"
    XRP_LEDGER_FOUNDATION_MAINNET_2 = "wss://xrpl.ws/"

    RIPPLE_MAINNET_1 = "wss://s1.ripple.com/"
    RIPPLE_MAINNET_2 = "wss://s2.ripple.com/"

    SOLOGENIC_MAINNET = "wss://x1.sologenic.org/"

    RIPPLE_TESTNET = "wss://s.altnet.rippletest.net/"

    RIPPLE_DEVNET = "wss://s.devnet.rippletest.net/"
